@@ -61,7 +61,7 @@ class BaseClient(object):
 
         self.default_headers = {}
 
-        self.user_agent = 'attune-python/1.0.0'
+        self.user_agent = 'attune-python/1.0.4'
 
     @property
     def user_agent(self):
@@ -212,7 +212,18 @@ class BaseClient(object):
         except ValueError:
             data = response.data
 
-        return self.__deserialize(data, response_type)
+        return self.__manual_deserialize(data, response_type)
+
+    def __manual_deserialize(self, data, klass):
+        if "RankedEntities" == klass:
+           r = model.RankedEntities()
+           r.cell = data.get('cell', None);
+           r.ranking = data.get('ranking', None);
+           r.status = data.get('status', None);
+           r.message = data.get('message', None);
+        else:
+           r = __deserialize(data, klass)
+        return r
 
     def __deserialize(self, data, klass):
         """
@@ -565,11 +576,11 @@ class Client(BaseClient):
     def get_bound_customer(self, anonymous_id, oauth_token=None, callback=None):
         return self.run(commands.BoundCustomer(self, args=(anonymous_id,), oauth_token=oauth_token), callback)
 
-    def get_rankings(self, ranking_params, oauth_token=None, callback=None):
+    def get_rankings(self, ranking_params, oauth_token=None, callback=None, offset=None, count=None):
         ranking_params.entity_source = ranking_params.entity_source or 'ids'
 
         if ranking_params.entity_source.upper() == 'IDS':
-            command = commands.GetRankingsPOST(self, args=(ranking_params,), oauth_token=oauth_token)
+            command = commands.GetRankingsPOST(self, args=(ranking_params,), offset=offset, count=count, oauth_token=oauth_token)
         else:
             command = commands.GetRankingsGET(self, args=(ranking_params,), oauth_token=oauth_token)
 
